@@ -5,6 +5,7 @@ import {
   FIXTURE_FOLDER,
   FIXTURE_URI,
   REPO_ROOT_FOLDER,
+  updateSnapshotUris,
 } from '../../../testing/fixtures'
 import Analyzer from '../analyser'
 import { getDefaultConfiguration } from '../config'
@@ -42,60 +43,29 @@ describe('analyze', () => {
       document: FIXTURE_DOCUMENT.INSTALL,
     })
     expect(diagnostics).toEqual([])
+    expect(loggerWarn).not.toHaveBeenCalled()
   })
 
-  it('returns a list of diagnostics for a file with a missing node', () => {
+  it('parses files with a missing node', () => {
     const diagnostics = analyzer.analyze({
       uri: CURRENT_URI,
       document: FIXTURE_DOCUMENT.MISSING_NODE,
     })
-    expect(diagnostics).not.toEqual([])
-    expect(diagnostics).toMatchInlineSnapshot(`
-      Array [
-        Object {
-          "message": "Syntax error: expected \\"fi\\" somewhere in the file",
-          "range": Object {
-            "end": Object {
-              "character": 0,
-              "line": 12,
-            },
-            "start": Object {
-              "character": 0,
-              "line": 12,
-            },
-          },
-          "severity": 2,
-          "source": "bash-language-server",
-        },
-      ]
-    `)
+    expect(diagnostics).toEqual([])
+    expect(loggerWarn).toHaveBeenCalledWith(
+      'Error while parsing dummy-uri.sh: syntax error',
+    )
   })
 
-  it('returns a list of diagnostics for a file with parsing errors', () => {
+  it('parses a file with parsing errors', () => {
     const diagnostics = analyzer.analyze({
       uri: CURRENT_URI,
       document: FIXTURE_DOCUMENT.PARSE_PROBLEMS,
     })
-    expect(diagnostics).not.toEqual([])
-    expect(diagnostics).toMatchInlineSnapshot(`
-      Array [
-        Object {
-          "message": "Failed to parse",
-          "range": Object {
-            "end": Object {
-              "character": 1,
-              "line": 9,
-            },
-            "start": Object {
-              "character": 0,
-              "line": 2,
-            },
-          },
-          "severity": 1,
-          "source": "bash-language-server",
-        },
-      ]
-    `)
+    expect(diagnostics).toEqual([])
+    expect(loggerWarn).toHaveBeenCalledWith(
+      'Error while parsing dummy-uri.sh: syntax error',
+    )
   })
 
   it('returns a list of diagnostics for a file with sourcing issues', async () => {
@@ -112,7 +82,7 @@ describe('analyze', () => {
     expect(diagnostics).toMatchInlineSnapshot(`
       Array [
         Object {
-          "message": "Source command could not be analyzed: expansion not supported.
+          "message": "Source command could not be analyzed: non-constant source not supported.
 
       Note that enabling the configuration flag \\"includeAllWorkspaceSymbols\\"
       would include all symbols in the workspace regardless of source commands.
@@ -153,7 +123,7 @@ describe('findDeclarationLocations', () => {
       word: './extension.inc',
       position: { character: 10, line: 2 },
     })
-    expect(result).toMatchInlineSnapshot(`
+    expect(updateSnapshotUris(result)).toMatchInlineSnapshot(`
       Array [
         Object {
           "range": Object {
@@ -166,7 +136,7 @@ describe('findDeclarationLocations', () => {
               "line": 0,
             },
           },
-          "uri": "file://${FIXTURE_FOLDER}extension.inc",
+          "uri": "file://__REPO_ROOT_FOLDER__/testing/fixtures/extension.inc",
         },
       ]
     `)
@@ -188,7 +158,7 @@ describe('findDeclarationLocations', () => {
       word: './scripts/tag-release.inc',
       position: { character: 10, line: 16 },
     })
-    expect(result).toMatchInlineSnapshot(`
+    expect(updateSnapshotUris(result)).toMatchInlineSnapshot(`
       Array [
         Object {
           "range": Object {
@@ -201,7 +171,7 @@ describe('findDeclarationLocations', () => {
               "line": 0,
             },
           },
-          "uri": "file://${REPO_ROOT_FOLDER}/scripts/tag-release.inc",
+          "uri": "file://__REPO_ROOT_FOLDER__/scripts/tag-release.inc",
         },
       ]
     `)
@@ -214,7 +184,7 @@ describe('findDeclarationLocations', () => {
       uri: CURRENT_URI,
       word: 'node_version',
     })
-    expect(result).toMatchInlineSnapshot(`
+    expect(updateSnapshotUris(result)).toMatchInlineSnapshot(`
       Array [
         Object {
           "range": Object {
@@ -239,7 +209,7 @@ describe('findDeclarationLocations', () => {
       uri: FIXTURE_URI.SCOPE,
       word: 'X',
     })
-    expect(result).toMatchInlineSnapshot(`
+    expect(updateSnapshotUris(result)).toMatchInlineSnapshot(`
       Array [
         Object {
           "range": Object {
@@ -252,7 +222,7 @@ describe('findDeclarationLocations', () => {
               "line": 12,
             },
           },
-          "uri": "file://${FIXTURE_FOLDER}scope.sh",
+          "uri": "file://__REPO_ROOT_FOLDER__/testing/fixtures/scope.sh",
         },
       ]
     `)
@@ -264,7 +234,7 @@ describe('findDeclarationLocations', () => {
       uri: FIXTURE_URI.SCOPE,
       word: 'i',
     })
-    expect(result).toMatchInlineSnapshot(`
+    expect(updateSnapshotUris(result)).toMatchInlineSnapshot(`
       Array [
         Object {
           "range": Object {
@@ -277,7 +247,7 @@ describe('findDeclarationLocations', () => {
               "line": 37,
             },
           },
-          "uri": "file://${FIXTURE_FOLDER}scope.sh",
+          "uri": "file://__REPO_ROOT_FOLDER__/testing/fixtures/scope.sh",
         },
       ]
     `)
@@ -434,12 +404,14 @@ describe('findDeclarationsMatchingWord', () => {
     })
 
     expect(
-      analyzer.findDeclarationsMatchingWord({
-        word: 'npm_config_logl',
-        uri: FIXTURE_URI.INSTALL,
-        exactMatch: false,
-        position: { line: 1000, character: 0 },
-      }),
+      updateSnapshotUris(
+        analyzer.findDeclarationsMatchingWord({
+          word: 'npm_config_logl',
+          uri: FIXTURE_URI.INSTALL,
+          exactMatch: false,
+          position: { line: 1000, character: 0 },
+        }),
+      ),
     ).toMatchInlineSnapshot(`
       Array [
         Object {
@@ -455,7 +427,7 @@ describe('findDeclarationsMatchingWord', () => {
                 "line": 40,
               },
             },
-            "uri": "file://${FIXTURE_FOLDER}install.sh",
+            "uri": "file://__REPO_ROOT_FOLDER__/testing/fixtures/install.sh",
           },
           "name": "npm_config_loglevel",
         },
@@ -472,12 +444,14 @@ describe('findDeclarationsMatchingWord', () => {
     ).toMatchInlineSnapshot(`Array []`)
 
     expect(
-      analyzer.findDeclarationsMatchingWord({
-        word: 'BLU',
-        uri: FIXTURE_URI.INSTALL,
-        exactMatch: false,
-        position: { line: 6, character: 9 },
-      }),
+      updateSnapshotUris(
+        analyzer.findDeclarationsMatchingWord({
+          word: 'BLU',
+          uri: FIXTURE_URI.INSTALL,
+          exactMatch: false,
+          position: { line: 6, character: 9 },
+        }),
+      ),
     ).toMatchInlineSnapshot(`
       Array [
         Object {
@@ -485,15 +459,15 @@ describe('findDeclarationsMatchingWord', () => {
           "location": Object {
             "range": Object {
               "end": Object {
-                "character": 19,
+                "character": 25,
                 "line": 6,
               },
               "start": Object {
-                "character": 0,
+                "character": 6,
                 "line": 6,
               },
             },
-            "uri": "file://${FIXTURE_FOLDER}extension.inc",
+            "uri": "file://__REPO_ROOT_FOLDER__/testing/fixtures/extension.inc",
           },
           "name": "BLUE",
         },
@@ -501,12 +475,14 @@ describe('findDeclarationsMatchingWord', () => {
     `)
 
     expect(
-      analyzer.findDeclarationsMatchingWord({
-        word: 'BLU',
-        uri: FIXTURE_URI.SOURCING,
-        exactMatch: false,
-        position: { line: 6, character: 9 },
-      }),
+      updateSnapshotUris(
+        analyzer.findDeclarationsMatchingWord({
+          word: 'BLU',
+          uri: FIXTURE_URI.SOURCING,
+          exactMatch: false,
+          position: { line: 6, character: 9 },
+        }),
+      ),
     ).toMatchInlineSnapshot(`
       Array [
         Object {
@@ -514,15 +490,15 @@ describe('findDeclarationsMatchingWord', () => {
           "location": Object {
             "range": Object {
               "end": Object {
-                "character": 19,
+                "character": 25,
                 "line": 6,
               },
               "start": Object {
-                "character": 0,
+                "character": 6,
                 "line": 6,
               },
             },
-            "uri": "file://${FIXTURE_FOLDER}extension.inc",
+            "uri": "file://__REPO_ROOT_FOLDER__/testing/fixtures/extension.inc",
           },
           "name": "BLUE",
         },
@@ -553,12 +529,14 @@ describe('findDeclarationsMatchingWord', () => {
     ).toMatchInlineSnapshot(`Array []`)
 
     expect(
-      analyzer.findDeclarationsMatchingWord({
-        word: 'BLU',
-        uri: FIXTURE_URI.SOURCING,
-        exactMatch: false,
-        position: { line: 6, character: 9 },
-      }),
+      updateSnapshotUris(
+        analyzer.findDeclarationsMatchingWord({
+          word: 'BLU',
+          uri: FIXTURE_URI.SOURCING,
+          exactMatch: false,
+          position: { line: 6, character: 9 },
+        }),
+      ),
     ).toMatchInlineSnapshot(`
       Array [
         Object {
@@ -566,15 +544,15 @@ describe('findDeclarationsMatchingWord', () => {
           "location": Object {
             "range": Object {
               "end": Object {
-                "character": 19,
+                "character": 25,
                 "line": 6,
               },
               "start": Object {
-                "character": 0,
+                "character": 6,
                 "line": 6,
               },
             },
-            "uri": "file://${FIXTURE_FOLDER}extension.inc",
+            "uri": "file://__REPO_ROOT_FOLDER__/testing/fixtures/extension.inc",
           },
           "name": "BLUE",
         },
@@ -604,7 +582,7 @@ describe('findDeclarationsMatchingWord', () => {
     expect(findWordFromLine('f', 0)).toEqual([])
 
     // First definition
-    expect(findWordFromLine('X', 3)).toMatchInlineSnapshot(`
+    expect(updateSnapshotUris(findWordFromLine('X', 3))).toMatchInlineSnapshot(`
       Array [
         Object {
           "kind": 13,
@@ -619,7 +597,7 @@ describe('findDeclarationsMatchingWord', () => {
                 "line": 2,
               },
             },
-            "uri": "file://${FIXTURE_FOLDER}scope.sh",
+            "uri": "file://__REPO_ROOT_FOLDER__/testing/fixtures/scope.sh",
           },
           "name": "X",
         },
@@ -627,7 +605,7 @@ describe('findDeclarationsMatchingWord', () => {
     `)
 
     // Local variable definition
-    expect(findWordFromLine('X', 13)).toMatchInlineSnapshot(`
+    expect(updateSnapshotUris(findWordFromLine('X', 13))).toMatchInlineSnapshot(`
       Array [
         Object {
           "containerName": "g",
@@ -643,7 +621,7 @@ describe('findDeclarationsMatchingWord', () => {
                 "line": 12,
               },
             },
-            "uri": "file://${FIXTURE_FOLDER}scope.sh",
+            "uri": "file://__REPO_ROOT_FOLDER__/testing/fixtures/scope.sh",
           },
           "name": "X",
         },
@@ -651,7 +629,7 @@ describe('findDeclarationsMatchingWord', () => {
     `)
 
     // Local function definition
-    expect(findWordFromLine('f', 23)).toMatchInlineSnapshot(`
+    expect(updateSnapshotUris(findWordFromLine('f', 23))).toMatchInlineSnapshot(`
       Array [
         Object {
           "containerName": "g",
@@ -667,7 +645,7 @@ describe('findDeclarationsMatchingWord', () => {
                 "line": 18,
               },
             },
-            "uri": "file://${FIXTURE_FOLDER}scope.sh",
+            "uri": "file://__REPO_ROOT_FOLDER__/testing/fixtures/scope.sh",
           },
           "name": "f",
         },
@@ -675,7 +653,7 @@ describe('findDeclarationsMatchingWord', () => {
     `)
 
     // Last definition
-    expect(findWordFromLine('X', 1000)).toMatchInlineSnapshot(`
+    expect(updateSnapshotUris(findWordFromLine('X', 1000))).toMatchInlineSnapshot(`
       Array [
         Object {
           "kind": 13,
@@ -690,14 +668,14 @@ describe('findDeclarationsMatchingWord', () => {
                 "line": 4,
               },
             },
-            "uri": "file://${FIXTURE_FOLDER}scope.sh",
+            "uri": "file://__REPO_ROOT_FOLDER__/testing/fixtures/scope.sh",
           },
           "name": "X",
         },
       ]
     `)
 
-    expect(findWordFromLine('f', 1000)).toMatchInlineSnapshot(`
+    expect(updateSnapshotUris(findWordFromLine('f', 1000))).toMatchInlineSnapshot(`
       Array [
         Object {
           "kind": 12,
@@ -712,7 +690,7 @@ describe('findDeclarationsMatchingWord', () => {
                 "line": 7,
               },
             },
-            "uri": "file://${FIXTURE_FOLDER}scope.sh",
+            "uri": "file://__REPO_ROOT_FOLDER__/testing/fixtures/scope.sh",
           },
           "name": "f",
         },
@@ -720,7 +698,7 @@ describe('findDeclarationsMatchingWord', () => {
     `)
 
     // Global variable defined inside a function
-    expect(findWordFromLine('GLOBAL_1', 1000)).toMatchInlineSnapshot(`
+    expect(updateSnapshotUris(findWordFromLine('GLOBAL_1', 1000))).toMatchInlineSnapshot(`
       Array [
         Object {
           "containerName": "g",
@@ -736,7 +714,7 @@ describe('findDeclarationsMatchingWord', () => {
                 "line": 13,
               },
             },
-            "uri": "file://${FIXTURE_FOLDER}scope.sh",
+            "uri": "file://__REPO_ROOT_FOLDER__/testing/fixtures/scope.sh",
           },
           "name": "GLOBAL_1",
         },
@@ -802,7 +780,12 @@ describe('initiateBackgroundAnalysis', () => {
       globPattern: defaultConfig.globPattern,
     })
 
-    expect(loggerWarn).not.toHaveBeenCalled()
+    expect(loggerWarn).toHaveBeenCalled()
+    expect(loggerWarn.mock.calls).toEqual([
+      [expect.stringContaining('missing-node.sh: syntax error')],
+      [expect.stringContaining('not-a-shell-script.sh: syntax error')],
+      [expect.stringContaining('parse-problems.sh: syntax error')],
+    ])
 
     // Intro, stats on glob, one file skipped due to shebang, and outro
     expect(filesParsed).toEqual(FIXTURE_FILES_MATCHING_GLOB)
@@ -868,8 +851,14 @@ describe('getAllVariables', () => {
 
     newAnalyzer.analyze({ uri, document })
 
-    expect(newAnalyzer.getAllVariables({ uri, position: { line: 20, character: 0 } }))
-      .toMatchInlineSnapshot(`
+    expect(
+      updateSnapshotUris(
+        newAnalyzer.getAllVariables({
+          uri,
+          position: { line: 20, character: 0 },
+        }),
+      ),
+    ).toMatchInlineSnapshot(`
       Array [
         Object {
           "kind": 13,
@@ -884,7 +873,7 @@ describe('getAllVariables', () => {
                 "line": 10,
               },
             },
-            "uri": "file://${FIXTURE_FOLDER}sourcing.sh",
+            "uri": "file://__REPO_ROOT_FOLDER__/testing/fixtures/sourcing.sh",
           },
           "name": "BOLD",
         },
@@ -901,7 +890,7 @@ describe('getAllVariables', () => {
                 "line": 4,
               },
             },
-            "uri": "file://${FIXTURE_FOLDER}extension.inc",
+            "uri": "file://__REPO_ROOT_FOLDER__/testing/fixtures/extension.inc",
           },
           "name": "RED",
         },
@@ -918,7 +907,7 @@ describe('getAllVariables', () => {
                 "line": 5,
               },
             },
-            "uri": "file://${FIXTURE_FOLDER}extension.inc",
+            "uri": "file://__REPO_ROOT_FOLDER__/testing/fixtures/extension.inc",
           },
           "name": "GREEN",
         },
@@ -927,15 +916,15 @@ describe('getAllVariables', () => {
           "location": Object {
             "range": Object {
               "end": Object {
-                "character": 19,
+                "character": 25,
                 "line": 6,
               },
               "start": Object {
-                "character": 0,
+                "character": 6,
                 "line": 6,
               },
             },
-            "uri": "file://${FIXTURE_FOLDER}extension.inc",
+            "uri": "file://__REPO_ROOT_FOLDER__/testing/fixtures/extension.inc",
           },
           "name": "BLUE",
         },
@@ -944,15 +933,15 @@ describe('getAllVariables', () => {
           "location": Object {
             "range": Object {
               "end": Object {
-                "character": 16,
+                "character": 23,
                 "line": 7,
               },
               "start": Object {
-                "character": 0,
+                "character": 7,
                 "line": 7,
               },
             },
-            "uri": "file://${FIXTURE_FOLDER}extension.inc",
+            "uri": "file://__REPO_ROOT_FOLDER__/testing/fixtures/extension.inc",
           },
           "name": "BOLD",
         },
@@ -961,15 +950,15 @@ describe('getAllVariables', () => {
           "location": Object {
             "range": Object {
               "end": Object {
-                "character": 17,
-                "line": 8,
+                "character": 19,
+                "line": 10,
               },
               "start": Object {
-                "character": 0,
-                "line": 8,
+                "character": 2,
+                "line": 10,
               },
             },
-            "uri": "file://${FIXTURE_FOLDER}extension.inc",
+            "uri": "file://__REPO_ROOT_FOLDER__/testing/fixtures/extension.inc",
           },
           "name": "RESET",
         },
