@@ -484,7 +484,6 @@ describe('server', () => {
       expect.arrayContaining([
         {
           data: {
-            name: 'rm',
             type: CompletionItemDataType.Executable,
           },
           kind: expect.any(Number),
@@ -564,6 +563,29 @@ describe('server', () => {
     expect(result && 'length' in result && result.length).toBeGreaterThanOrEqual(50)
   })
 
+  it('responds to onCompletion with empty list when the following characters is not an empty string or whitespace', async () => {
+    const { connection } = await initializeServer()
+
+    const onCompletion = connection.onCompletion.mock.calls[0][0]
+
+    const result = await onCompletion(
+      {
+        textDocument: {
+          uri: FIXTURE_URI.INSTALL,
+        },
+        position: {
+          // {
+          line: 271,
+          character: 21,
+        },
+      },
+      {} as any,
+      {} as any,
+    )
+
+    expect(result).toEqual([])
+  })
+
   it('responds to onCompletion with empty list when word is a comment', async () => {
     const { connection } = await initializeServer()
 
@@ -634,7 +656,6 @@ describe('server', () => {
       Array [
         Object {
           "data": Object {
-            "name": "BLUE",
             "type": 3,
           },
           "documentation": Object {
@@ -666,7 +687,6 @@ describe('server', () => {
       Array [
         Object {
           "data": Object {
-            "name": "add_a_user",
             "type": 3,
           },
           "documentation": Object {
@@ -708,7 +728,6 @@ describe('server', () => {
       Array [
         Object {
           "data": Object {
-            "name": "BOLD",
             "type": 3,
           },
           "documentation": undefined,
@@ -747,7 +766,6 @@ describe('server', () => {
       Array [
         Object {
           "data": Object {
-            "name": "BOLD",
             "type": 3,
           },
           "documentation": undefined,
@@ -756,7 +774,6 @@ describe('server', () => {
         },
         Object {
           "data": Object {
-            "name": "RED",
             "type": 3,
           },
           "documentation": Object {
@@ -768,7 +785,6 @@ describe('server', () => {
         },
         Object {
           "data": Object {
-            "name": "GREEN",
             "type": 3,
           },
           "documentation": Object {
@@ -780,7 +796,6 @@ describe('server', () => {
         },
         Object {
           "data": Object {
-            "name": "BLUE",
             "type": 3,
           },
           "documentation": Object {
@@ -792,7 +807,6 @@ describe('server', () => {
         },
         Object {
           "data": Object {
-            "name": "RESET",
             "type": 3,
           },
           "documentation": Object {
