@@ -3,7 +3,7 @@ import * as FuzzySearch from 'fuzzy-search'
 import fetch from 'node-fetch'
 import * as URI from 'urijs'
 import * as url from 'url'
-import { isDeepStrictEqual, promisify } from 'util'
+import { isDeepStrictEqual } from 'util'
 import * as LSP from 'vscode-languageserver/node'
 import { TextDocument } from 'vscode-languageserver-textdocument'
 import * as Parser from 'web-tree-sitter'
@@ -22,8 +22,6 @@ import { analyzeShebang } from './util/shebang'
 import * as sourcing from './util/sourcing'
 import * as TreeSitterUtil from './util/tree-sitter'
 
-const readFileAsync = promisify(fs.readFile)
-
 type AnalyzedDocument = {
   document: TextDocument
   globalDeclarations: GlobalDeclarations
@@ -59,9 +57,6 @@ export default class Analyzer {
   /**
    * Analyze the given document, cache the tree-sitter AST, and iterate over the
    * tree to find declarations.
-   *
-   * Returns all, if any, syntax errors that occurred while parsing the file.
-   *
    */
   public analyze({
     document,
@@ -70,11 +65,12 @@ export default class Analyzer {
     document: TextDocument
     uri: string
   }): LSP.Diagnostic[] {
+    const diagnostics: LSP.Diagnostic[] = []
     const fileContent = document.getText()
 
     const tree = this.parser.parse(fileContent)
 
-    const { diagnostics, globalDeclarations } = getGlobalDeclarations({ tree, uri })
+    const globalDeclarations = getGlobalDeclarations({ tree, uri })
 
     const sourceCommands = sourcing.getSourceCommands({
       fileUri: uri,
@@ -117,24 +113,10 @@ export default class Analyzer {
         })
     }
 
-    function findMissingNodes(node: Parser.SyntaxNode) {
-      if (node.isMissing()) {
-        diagnostics.push(
-          LSP.Diagnostic.create(
-            TreeSitterUtil.range(node),
-            `Syntax error: expected "${node.type}" somewhere in the file`,
-            LSP.DiagnosticSeverity.Warning,
-            undefined,
-            'bash-language-server',
-          ),
-        )
-      } else if (node.hasError()) {
-        node.children.forEach(findMissingNodes)
-      }
+    if (tree.rootNode.hasError()) {
+      logger.warn(`Error while parsing ${uri}: syntax error`)
     }
 
-    findMissingNodes(tree.rootNode)
-
     return diagnostics
   }
 
@@ -194,7 +176,7 @@ export default class Analyzer {
       const uri = url.pathToFileURL(filePath).href
 
       try {
-        const fileContent = await readFileAsync(filePath, 'utf8')
+        const fileContent = await fs.promises.readFile(filePath, 'utf8')
         const { shebang, shellDialect } = analyzeShebang(fileContent)
         if (shebang && !shellDialect) {
           logger.info(
@@ -361,6 +343,13 @@ export default class Analyzer {
     return getAllDeclarationsInTree({ uri, tree })
   }
 
+  /**
+   * Get the document for the given URI.
+   */
+  public getDocument(uri: string): TextDocument | undefined {
+    return this.uriToAnalyzedDocument[uri]?.document
+  }
+
   // TODO: move somewhere else than the analyzer...
   public async getExplainshellDocumentation({
     params,
@@ -391,9 +380,8 @@ export default class Analyzer {
       return {}
     }
 
-    const cmd = analyzedDocument.document
-      .getText()
-      .slice(interestingNode.startIndex, interestingNode.endIndex)
+    const cmd = interestingNode.text
+
     type ExplainshellResponse = {
       matches?: Array<{ helpHTML: string; start: number; end: number }>
     }
