@@ -14,6 +14,7 @@ import Executables from './executables'
 import { initializeParser } from './parser'
 import * as ReservedWords from './reserved-words'
 import { Linter } from './shellcheck'
+import { SNIPPETS } from './snippets'
 import { BashCompletionItem, CompletionItemDataType } from './types'
 import { uniqueBasedOnHash } from './util/array'
 import { logger, setLogConnection, setLogLevel } from './util/logger'
@@ -288,15 +289,8 @@ export default class BashServer {
   public async analyzeAndLintDocument(document: TextDocument) {
     const { uri } = document
 
-    let diagnostics: LSP.Diagnostic[] = []
-
     // Load the tree for the modified contents into the analyzer:
-    const analyzeDiagnostics = this.analyzer.analyze({ uri, document })
-    // Treesitter's diagnostics can be a bit inaccurate, so we only merge the
-    // analyzer's diagnostics if the setting is enabled:
-    if (this.config.highlightParsingErrors) {
-      diagnostics = diagnostics.concat(analyzeDiagnostics)
-    }
+    let diagnostics = this.analyzer.analyze({ uri, document })
 
     // Run ShellCheck diagnostics:
     if (this.linter) {
@@ -344,7 +338,6 @@ export default class BashServer {
         label: symbol.name,
         kind: symbolKindToCompletionKind(symbol.kind),
         data: {
-          name: symbol.name,
           type: CompletionItemDataType.Symbol,
         },
         documentation:
@@ -437,21 +430,34 @@ export default class BashServer {
         character: Math.max(params.position.character - 1, 0),
       },
     })
+
     this.logRequest({ request: 'onCompletion', params, word })
 
-    if (word && word.startsWith('#')) {
+    if (word?.startsWith('#')) {
       // Inside a comment block
       return []
     }
-    if (word && word === '{') {
+
+    if (word === '{') {
       // We should not complete when it is not prefixed by a $.
-      // This case needs to be here
-      // because { is a completionProvider triggerCharacter.
+      // This case needs to be here as "{" is a completionProvider triggerCharacter.
       return []
     }
 
+    if (!word) {
+      const nextCharacter = this.analyzer.getDocument(params.textDocument.uri)?.getText({
+        start: params.position,
+        end: { ...params.position, character: params.position.character + 1 },
+      })
+      const isNextCharacterSpaceOrEmpty = nextCharacter === '' || nextCharacter === ' '
+      if (!isNextCharacterSpaceOrEmpty) {
+        // We are in the middle of something, so don't complete
+        return []
+      }
+    }
+
     let options: string[] = []
-    if (word && word.startsWith('-')) {
+    if (word?.startsWith('-')) {
       const commandName = this.analyzer.commandNameAtPoint(
         params.textDocument.uri,
         params.position.line,
@@ -503,7 +509,6 @@ export default class BashServer {
       label: reservedWord,
       kind: LSP.CompletionItemKind.Keyword,
       data: {
-        name: reservedWord,
         type: CompletionItemDataType.ReservedWord,
       },
     }))
@@ -516,7 +521,6 @@ export default class BashServer {
           label: executable,
           kind: LSP.CompletionItemKind.Function,
           data: {
-            name: executable,
             type: CompletionItemDataType.Executable,
           },
         }
@@ -526,7 +530,6 @@ export default class BashServer {
       label: builtin,
       kind: LSP.CompletionItemKind.Function,
       data: {
-        name: builtin,
         type: CompletionItemDataType.Builtin,
       },
     }))
@@ -535,7 +538,6 @@ export default class BashServer {
       label: option,
       kind: LSP.CompletionItemKind.Constant,
       data: {
-        name: option,
         type: CompletionItemDataType.Symbol,
       },
     }))
@@ -546,6 +548,7 @@ export default class BashServer {
       ...programCompletions,
       ...builtinsCompletions,
       ...optionsCompletions,
+      ...SNIPPETS,
     ]
 
     if (word) {
@@ -560,10 +563,11 @@ export default class BashServer {
     item: LSP.CompletionItem,
   ): Promise<LSP.CompletionItem> {
     const {
-      data: { name, type },
+      label,
+      data: { type },
     } = item as BashCompletionItem
 
-    logger.debug(`onCompletionResolve name=${name} type=${type}`)
+    logger.debug(`onCompletionResolve label=${label} type=${type}`)
 
     try {
       let documentation = null
@@ -573,7 +577,7 @@ export default class BashServer {
         type === CompletionItemDataType.Builtin ||
         type === CompletionItemDataType.ReservedWord
       ) {
-        documentation = await getShellDocumentation({ word: name })
+        documentation = await getShellDocumentation({ word: label })
       }
 
       return documentation
